@@ -1,6 +1,6 @@
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # Mobius Forensic Toolkit
-# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024 Eduardo Aguiar
+# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -22,7 +22,6 @@ import os.path
 import mobius
 import pymobius
 from gi.repository import GLib
-from gi.repository import GObject
 from gi.repository import Gdk
 from gi.repository import GdkPixbuf
 from gi.repository import Gtk
@@ -65,12 +64,11 @@ def import_json(f):
     categories = json.load(fp)
 
     # insert data
-    category_manager = mobius.core.category_manager()
-    transaction = category_manager.new_transaction()
-    category_manager.clear()
+    transaction = mobius.framework.new_category_transaction()
+    mobius.framework.remove_categories()
 
     for d_category in categories:
-        category = category_manager.new_category(d_category.get('id'))
+        category = mobius.framework.new_category(d_category.get('id'))
         category.name = d_category.get('name')
         category.description = d_category.get('description')
         category.icon_data = mobius.decoder.base64(d_category.get('icon'))
@@ -92,11 +90,14 @@ def import_json(f):
 def export_json(f):
     # generate data
     categories = []
-    category_manager = mobius.core.category_manager()
 
-    for category in category_manager.get_categories():
-        d_category = {'id': category.id, 'name': category.name, 'description': category.description,
-                      'icon': mobius.encoder.base64(category.icon_data)}
+    for category in mobius.framework.get_categories():
+        d_category = {
+            'id': category.id,
+            'name': category.name,
+            'description': category.description,
+            'icon': mobius.encoder.base64(category.icon_data)
+        }
 
         attrlist = []
         for attr in category.get_attributes():
@@ -121,23 +122,22 @@ def export_json(f):
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # @brief Widget
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-class Widget(Gtk.VBox):
+class Widget(object):
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     # @brief Initialize widget
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-    def __init__(self, mediator):
-        GObject.GObject.__init__(self)
-        self.__mediator = mediator.copy()
-        self.__factory = self.__mediator.call('ui.new-factory')
-        self.set_border_width(5)
-        self.set_spacing(5)
-        self.show()
+    def __init__(self):
+        self.__widget = mobius.ui.box(mobius.ui.box.orientation_vertical)
+        self.__mediator = pymobius.mediator.copy()
+        self.__widget.set_border_width(5)
+        self.__widget.set_spacing(5)
+        self.__widget.set_visible(True)
 
         # menubar
         menubar = Gtk.MenuBar()
         menubar.show()
-        self.pack_start(menubar, False, False, 0)
+        self.__widget.add_child(menubar, mobius.ui.box.fill_none)
 
         item = Gtk.MenuItem.new_with_mnemonic('_File')
         item.show()
@@ -169,17 +169,17 @@ class Widget(Gtk.VBox):
         # hpaned
         hpaned = Gtk.HPaned()
         hpaned.show()
-        self.pack_start(hpaned, True, True, 0)
+        self.__widget.add_child(hpaned, mobius.ui.box.fill_with_widget)
 
         # category listview
-        vbox1 = Gtk.VBox()
+        vbox1 = mobius.ui.box(mobius.ui.box.orientation_vertical)
         vbox1.set_spacing(5)
-        vbox1.show()
-        hpaned.pack1(vbox1, True, True)
+        vbox1.set_visible(True)
+        hpaned.pack1(vbox1.get_ui_widget(), True, True)
 
         frame = Gtk.Frame()
         frame.show()
-        vbox1.pack_start(frame, True, True, 0)
+        vbox1.add_child(frame, mobius.ui.box.fill_with_widget)
 
         sw = Gtk.ScrolledWindow()
         sw.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC)
@@ -210,24 +210,26 @@ class Widget(Gtk.VBox):
         self.category_listview.append_column(tvcolumn)
 
         # buttons
-        hbox = Gtk.HBox()
-        hbox.show()
-        vbox1.pack_end(hbox, False, True, 0)
+        hbox = mobius.ui.box(mobius.ui.box.orientation_horizontal)
+        hbox.set_visible(True)
+        vbox1.add_child(hbox, mobius.ui.box.fill_none)
 
-        image = Gtk.Image.new_from_icon_name('list-add', Gtk.IconSize.BUTTON)
-        button = Gtk.Button.new_with_mnemonic("_Add")
-        button.set_image(image)
-        button.connect('clicked', self.on_category_add)
-        button.show()
-        hbox.pack_start(button, False, True, 0)
+        button = mobius.ui.button()
+        button.set_icon_by_name('list-add')
+        button.set_text("_Add")
+        button.set_visible(True)
+        button.set_callback('clicked', self.__on_category_add)
+        hbox.add_child(button, mobius.ui.box.fill_none)
 
-        image = Gtk.Image.new_from_icon_name('list-remove', Gtk.IconSize.BUTTON)
-        self.remove_button = Gtk.Button.new_with_mnemonic("_Remove")
-        self.remove_button.set_image(image)
-        self.remove_button.connect('clicked', self.on_category_remove)
-        self.remove_button.set_sensitive(False)
-        self.remove_button.show()
-        hbox.pack_start(self.remove_button, False, True, 0)
+        hbox.add_filler()
+
+        self.__remove_button = mobius.ui.button()
+        self.__remove_button.set_icon_by_name('list-remove')
+        self.__remove_button.set_text("_Remove")
+        self.__remove_button.set_sensitive(False)
+        self.__remove_button.set_visible(True)
+        self.__remove_button.set_callback('clicked', self.__on_category_remove)
+        hbox.add_child(self.__remove_button, mobius.ui.box.fill_none)
 
         # notebook
         notebook = Gtk.Notebook()
@@ -235,22 +237,22 @@ class Widget(Gtk.VBox):
         hpaned.pack2(notebook, True, True)
 
         # page: general
-        vbox2 = Gtk.VBox()
+        vbox2 = mobius.ui.box(mobius.ui.box.orientation_vertical)
         vbox2.set_border_width(5)
-        vbox2.show()
-        notebook.append_page(vbox2, Gtk.Label.new('General'))
+        vbox2.set_visible(True)
+        notebook.append_page(vbox2.get_ui_widget(), mobius.ui.label('General').get_ui_widget())
 
         grid = Gtk.Grid.new()
         grid.set_row_spacing(10)
         grid.set_column_spacing(5)
         grid.show()
-        vbox2.pack_start(grid, True, True, 0)
+        vbox2.add_child(grid, mobius.ui.box.fill_with_widget)
 
-        label = Gtk.Label.new()
+        label = mobius.ui.label()
         label.set_markup('<b>ID</b>')
-        label.set_xalign(1.0)
-        label.show()
-        grid.attach(label, 0, 0, 1, 1)
+        label.set_halign(mobius.ui.label.align_right)
+        label.set_visible(True)
+        grid.attach(label.get_ui_widget(), 0, 0, 1, 1)
 
         self.category_id_entry = Gtk.Entry()
         self.category_id_entry.set_editable(False)
@@ -259,48 +261,45 @@ class Widget(Gtk.VBox):
         self.category_id_entry.show()
         grid.attach(self.category_id_entry, 1, 0, 2, 1)
 
-        label = Gtk.Label.new()
+        label = mobius.ui.label()
         label.set_markup('<b>Name</b>')
-        label.set_xalign(1.0)
-        label.show()
-        grid.attach(label, 0, 1, 1, 1)
+        label.set_halign(mobius.ui.label.align_right)
+        label.set_visible(True)
+        grid.attach(label.get_ui_widget(), 0, 1, 1, 1)
 
         self.category_name_entry = Gtk.Entry()
         self.category_name_entry.connect('changed', self.on_category_name_changed)
         self.category_name_entry.show()
         grid.attach(self.category_name_entry, 1, 1, 2, 1)
 
-        label = Gtk.Label.new()
+        label = mobius.ui.label()
         label.set_markup('<b>Icon</b>')
-        label.set_xalign(1.0)
-        label.show()
-        grid.attach(label, 0, 2, 1, 1)
+        label.set_halign(mobius.ui.label.align_right)
+        label.set_visible(True)
+        grid.attach(label.get_ui_widget(), 0, 2, 1, 1)
 
-        self.category_icon_button = Gtk.Button()
-        self.category_icon_button.connect('clicked', self.on_category_icon_edit)
-        self.category_icon_button.set_hexpand(False)
-        self.category_icon_button.show()
+        icon = mobius.ui.new_icon_by_name('image-missing', mobius.ui.icon.size_dnd)
+        self.__category_icon_button = mobius.ui.button()
+        self.__category_icon_button.set_icon(icon)
+        self.__category_icon_button.set_visible(True)
+        self.__category_icon_button.set_callback('clicked', self.__on_category_icon_edit)
 
-        self.category_image = Gtk.Image.new_from_icon_name("image-missing", Gtk.IconSize.BUTTON)
-        self.category_image.show()
-        self.category_icon_button.add(self.category_image)
+        grid.attach(self.__category_icon_button.get_ui_widget(), 1, 2, 1, 1)
 
-        grid.attach(self.category_icon_button, 1, 2, 1, 1)
-
-        placeholder = Gtk.Label.new(' ')
-        placeholder.show()
-        grid.attach(placeholder, 2, 0, 1, 1)
+        placeholder = mobius.ui.label(' ')
+        placeholder.set_visible(True)
+        grid.attach(placeholder.get_ui_widget(), 2, 0, 1, 1)
 
         # page: attributes
-        vbox_page = Gtk.VBox()
+        vbox_page = mobius.ui.box(mobius.ui.box.orientation_vertical)
         vbox_page.set_spacing(5)
-        vbox_page.show()
-        notebook.append_page(vbox_page, Gtk.Label.new('Attributes'))
+        vbox_page.set_visible(True)
+        notebook.append_page(vbox_page.get_ui_widget(), mobius.ui.label('Attributes').get_ui_widget())
 
         sw = Gtk.ScrolledWindow()
         sw.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
         sw.show()
-        vbox_page.pack_start(sw, True, True, 0)
+        vbox_page.add_child(sw, mobius.ui.box.fill_with_widget)
 
         # attributes listview
         datastore = Gtk.ListStore.new([str, str, str])
@@ -332,48 +331,52 @@ class Widget(Gtk.VBox):
         sw.add(self.attribute_listview)
 
         # value_mask
-        hbox = Gtk.HBox()
-        hbox.set_spacing(3)
-        hbox.show()
-        vbox_page.pack_start(hbox, False, True, 0)
+        hbox = mobius.ui.box(mobius.ui.box.orientation_horizontal)
+        hbox.set_spacing(5)
+        hbox.set_visible(True)
+        vbox_page.add_child(hbox, mobius.ui.box.fill_none)
 
-        label = Gtk.Label.new()
-        label.set_markup('<b>value mask</b>')
-        label.show()
-        hbox.pack_start(label, False, True, 0)
+        label = mobius.ui.label()
+        label.set_markup('<b>Value mask</b>')
+        label.set_visible(True)
+        hbox.add_child(label, mobius.ui.box.fill_none)
 
         self.value_mask_entry = Gtk.Entry()
         self.value_mask_entry.connect('changed', self.on_value_mask_changed)
         self.value_mask_entry.show()
-        hbox.pack_start(self.value_mask_entry, True, True, 0)
+        hbox.add_child(self.value_mask_entry, mobius.ui.box.fill_with_widget)
 
         # attribute buttons
-        hbox = Gtk.HBox()
-        hbox.show()
-        vbox_page.pack_start(hbox, False, True, 0)
+        hbox = mobius.ui.box(mobius.ui.box.orientation_horizontal)
+        hbox.set_visible(True)
+        vbox_page.add_child(hbox, mobius.ui.box.fill_none)
 
-        self.add_attr_button = Gtk.Button.new_from_icon_name('list-add', Gtk.IconSize.BUTTON)
-        self.add_attr_button.connect('clicked', self.on_attribute_add)
-        self.add_attr_button.show()
-        hbox.pack_start(self.add_attr_button, False, True, 0)
+        self.__add_attr_button = mobius.ui.button()
+        self.__add_attr_button.set_icon_by_name('list-add')
+        self.__add_attr_button.set_visible(True)
+        self.__add_attr_button.set_callback('clicked', self.__on_attribute_add)
+        hbox.add_child(self.__add_attr_button, mobius.ui.box.fill_none)
 
-        self.remove_attr_button = Gtk.Button.new_from_icon_name('list-remove', Gtk.IconSize.BUTTON)
-        self.remove_attr_button.set_sensitive(False)
-        self.remove_attr_button.connect('clicked', self.on_attribute_remove)
-        self.remove_attr_button.show()
-        hbox.pack_start(self.remove_attr_button, False, True, 0)
+        self.__remove_attr_button = mobius.ui.button()
+        self.__remove_attr_button.set_icon_by_name('list-remove')
+        self.__remove_attr_button.set_sensitive(False)
+        self.__remove_attr_button.set_visible(True)
+        self.__remove_attr_button.set_callback('clicked', self.__on_attribute_remove)
+        hbox.add_child(self.__remove_attr_button, mobius.ui.box.fill_none)
 
-        self.up_attr_button = Gtk.Button.new_from_icon_name('go-up', Gtk.IconSize.BUTTON)
-        self.up_attr_button.set_sensitive(False)
-        self.up_attr_button.connect('clicked', self.on_attribute_up)
-        self.up_attr_button.show()
-        hbox.pack_start(self.up_attr_button, False, True, 0)
+        self.__up_attr_button = mobius.ui.button()
+        self.__up_attr_button.set_icon_by_name('go-up')
+        self.__up_attr_button.set_sensitive(False)
+        self.__up_attr_button.set_visible(True)
+        self.__up_attr_button.set_callback('clicked', self.__on_attribute_up)
+        hbox.add_child(self.__up_attr_button, mobius.ui.box.fill_none)
 
-        self.down_attr_button = Gtk.Button.new_from_icon_name('go-down', Gtk.IconSize.BUTTON)
-        self.down_attr_button.set_sensitive(False)
-        self.down_attr_button.connect('clicked', self.on_attribute_down)
-        self.down_attr_button.show()
-        hbox.pack_start(self.down_attr_button, False, True, 0)
+        self.__down_attr_button = mobius.ui.button()
+        self.__down_attr_button.set_icon_by_name('go-down')
+        self.__down_attr_button.set_sensitive(False)
+        self.__down_attr_button.set_visible(True)
+        self.__down_attr_button.set_callback('clicked', self.__on_attribute_down)
+        hbox.add_child(self.__down_attr_button, mobius.ui.box.fill_none)
 
         # flags
         self.is_selecting = False  # selecting new category
@@ -382,6 +385,12 @@ class Widget(Gtk.VBox):
 
         self.populate_category_listview()
 
+    # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+    # @brief Get internal widget
+    # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+    def get_widget(self):
+        return self.__widget
+
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     # @brief Populate category listview
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -389,9 +398,7 @@ class Widget(Gtk.VBox):
         model = self.category_listview.get_model()
         model.clear()
 
-        category_manager = mobius.core.category_manager()
-
-        for category in category_manager.get_categories():
+        for category in mobius.framework.get_categories():
             icon = self.__render_icon(category)
             model.append((icon, category.name, category))
 
@@ -489,19 +496,23 @@ class Widget(Gtk.VBox):
 
         # fill info
         if treeiter:
-            icon = model.get_value(treeiter, CATEGORY_ICON)
             category = model.get_value(treeiter, CATEGORY_OBJ)
 
             self.category_id_entry.set_text(category.id)
             self.category_name_entry.set_text(category.name or '')
-            self.category_image.set_from_pixbuf(icon)
+
+            icon = mobius.ui.new_icon_from_data(category.icon_data, mobius.ui.icon.size_dnd)
+            self.__category_icon_button.set_icon(icon)
+
             self.populate_attribute_listview(category)
             self.category = category
 
         else:
             self.category_id_entry.set_text('')
             self.category_name_entry.set_text('')
-            self.category_image.clear()
+            icon = mobius.ui.new_icon_by_name('image-missing', mobius.ui.icon.size_dnd)
+            self.__category_icon_button.set_icon(icon)
+
             attr_model = self.attribute_listview.get_model()
             attr_model.clear()
             self.category = None
@@ -510,15 +521,15 @@ class Widget(Gtk.VBox):
 
         # enable/disable widgets
         enabled = treeiter is not None
-        self.remove_button.set_sensitive(enabled)
+        self.__remove_button.set_sensitive(enabled)
         self.category_name_entry.set_sensitive(enabled)
-        self.category_icon_button.set_sensitive(enabled)
-        self.add_attr_button.set_sensitive(enabled)
+        self.__category_icon_button.set_sensitive(enabled)
+        self.__add_attr_button.set_sensitive(enabled)
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     # @brief handle category add
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-    def on_category_add(self, widget, *args):
+    def __on_category_add(self):
 
         # show dialog to enter category ID and Name
         dialog = Gtk.Dialog(title='Creating category', modal=True)
@@ -534,18 +545,18 @@ class Widget(Gtk.VBox):
         grid.show()
         dialog.vbox.pack_start(grid, True, True, 0)
 
-        label = Gtk.Label.new('ID')
-        label.set_xalign(1.0)
-        label.show()
+        label = mobius.ui.label('ID')
+        label.set_halign(mobius.ui.label.align_right)
+        label.set_visible(True)
         grid.attach(label, 0, 0, 1, 1)
 
         dialog.id_entry = Gtk.Entry()
         dialog.id_entry.show()
         grid.attach(dialog.id_entry, 1, 0, 1, 1)
 
-        label = Gtk.Label.new('Name')
-        label.set_xalign(1.0)
-        label.show()
+        label = mobius.ui.label('Name')
+        label.set_halign(mobius.ui.label.align_right)
+        label.set_visible(True)
         grid.attach(label, 0, 1, 1, 1)
 
         dialog.name_entry = Gtk.Entry()
@@ -560,8 +571,7 @@ class Widget(Gtk.VBox):
         # if user pressed OK, create category
         if rc == Gtk.ResponseType.OK and cat_id:
             # create category
-            category_manager = mobius.core.category_manager()
-            category = category_manager.new_category(cat_id)
+            category = mobius.framework.new_category(cat_id)
             category.name = cat_name
 
             # update window
@@ -575,7 +585,7 @@ class Widget(Gtk.VBox):
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     # @brief handle category remove
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-    def on_category_remove(self, widget, *args):
+    def __on_category_remove(self):
         selection = self.category_listview.get_selection()
         model, treeiter = selection.get_selected()
 
@@ -594,8 +604,7 @@ class Widget(Gtk.VBox):
                 return
 
             # remove category
-            category_manager = mobius.core.category_manager()
-            category_manager.remove_category(category.id)
+            mobius.framework.remove_category(category.id)
 
             # update window
             has_next = model.remove(treeiter)
@@ -619,7 +628,7 @@ class Widget(Gtk.VBox):
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     # @brief handle category icon edition
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-    def on_category_icon_edit(self, widget, *args):
+    def __on_category_icon_edit(self):
 
         # choose file
         fs = Gtk.FileChooserDialog(title='Choose 64x64 icon filename')
@@ -651,8 +660,8 @@ class Widget(Gtk.VBox):
         if treeiter:
             category = model.get_value(treeiter, CATEGORY_OBJ)
             category.icon_data = resize_icon_data(data)
-            icon = self.__render_icon(category)
-            self.category_image.set_from_pixbuf(icon)
+            icon = mobius.ui.new_icon_from_data(category.icon_data, mobius.ui.icon.size_dnd)
+            self.__category_icon_button.set_icon(icon)
             model.set_value(treeiter, CATEGORY_ICON, icon)
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -662,8 +671,8 @@ class Widget(Gtk.VBox):
         icon = None
 
         if category.icon_data:
-            image_buffer = self.__factory.new_image_buffer_from_data(category.icon_data, 32, 32)
-            icon = image_buffer.get_ui_widget()
+            image = mobius.ui.new_icon_from_data(category.icon_data, mobius.ui.icon.size_dnd)
+            icon = image.get_ui_widget().get_pixbuf()
 
         return icon
 
@@ -692,14 +701,14 @@ class Widget(Gtk.VBox):
         down_enabled = enabled and model.iter_next(treeiter) is not None
 
         self.value_mask_entry.set_sensitive(enabled)
-        self.remove_attr_button.set_sensitive(enabled)
-        self.up_attr_button.set_sensitive(up_enabled)
-        self.down_attr_button.set_sensitive(down_enabled)
+        self.__remove_attr_button.set_sensitive(enabled)
+        self.__up_attr_button.set_sensitive(up_enabled)
+        self.__down_attr_button.set_sensitive(down_enabled)
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     # @brief handle attribute add
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-    def on_attribute_add(self, widget, *args):
+    def __on_attribute_add(self):
         model = self.attribute_listview.get_model()
         treeiter = model.append(('<ID>', '<NAME>', ''))
         path = model.get_path(treeiter)
@@ -707,9 +716,9 @@ class Widget(Gtk.VBox):
         self.attribute_listview.set_cursor(path, column, True)
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-    # @brief handle attribute remotion
+    # @brief Handle attribute remotion
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-    def on_attribute_remove(self, widget, *args):
+    def __on_attribute_remove(self):
         selection = self.attribute_listview.get_selection()
         model, treeiter = selection.get_selected()
 
@@ -725,9 +734,9 @@ class Widget(Gtk.VBox):
                 selection.select_iter(treeiter)
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-    # @brief handle move up
+    # @brief Handle move up
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-    def on_attribute_up(self, widget, *args):
+    def __on_attribute_up(self):
         model, treeiter = self.attribute_listview.get_selection().get_selected()
 
         if treeiter:
@@ -743,14 +752,14 @@ class Widget(Gtk.VBox):
             self.attribute_listview.scroll_to_cell(dest_row)
 
             if dest_row == 0:
-                self.up_attr_button.set_sensitive(False)
+                self.__up_attr_button.set_sensitive(False)
 
-            self.down_attr_button.set_sensitive(True)
+            self.__down_attr_button.set_sensitive(True)
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-    # @brief handle move down
+    # @brief Handle move down
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-    def on_attribute_down(self, widget, *args):
+    def __on_attribute_down(self):
         model, treeiter = self.attribute_listview.get_selection().get_selected()
 
         if treeiter:
@@ -766,9 +775,9 @@ class Widget(Gtk.VBox):
             self.attribute_listview.scroll_to_cell(dest_row)
 
             if dest_row + 1 >= len(model):
-                self.down_attr_button.set_sensitive(False)
+                self.__down_attr_button.set_sensitive(False)
 
-            self.up_attr_button.set_sensitive(True)
+            self.__up_attr_button.set_sensitive(True)
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     # @brief handle attribute ID edition
@@ -859,7 +868,7 @@ def on_activate(item_id):
     working_area = pymobius.mediator.call('ui.working-area.get', EXTENSION_ID)
 
     if not working_area:
-        widget = Widget(pymobius.mediator.copy())
+        widget = Widget()
         icon_path = pymobius.mediator.call('extension.get-icon-path', EXTENSION_ID)
 
         working_area = pymobius.mediator.call('ui.working-area.new', EXTENSION_ID)
