@@ -3,7 +3,7 @@
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -25,6 +25,8 @@
 #include <string>
 #include <vector>
 
+class const_reference;
+
 namespace mobius
 {
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -63,6 +65,8 @@ public:
   bytearray (const char *);
   bytearray (const std::string&);
   bytearray (const uint8_t *, size_type);
+  bytearray (const uint8_t, size_type);
+  bytearray (const_iterator, const_iterator);
   bytearray (const bytearray&) = default;
   bytearray (bytearray&&) noexcept = default;
   bytearray (const std::initializer_list<uint8_t>&);
@@ -77,6 +81,8 @@ public:
   bytearray& operator= (bytearray&&) noexcept = default;
   bytearray& operator^= (const bytearray&) noexcept;
   bytearray& operator+= (const bytearray&);
+  bytearray& operator<<= (int) noexcept;
+  bytearray& operator>>= (int) noexcept;
 
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   //! \brief check if another bytearray is equal to *this
@@ -90,7 +96,7 @@ public:
   };
 
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  //! \brief Check if bytearray is valid
+  //! \brief Check if bytearray is not empty
   //! \return true/false
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   operator bool () const noexcept
@@ -240,21 +246,23 @@ public:
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   // Prototypes
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  void fill (value_type) noexcept;
-  void random () noexcept;
+  std::uint64_t count (std::uint8_t) const noexcept;
   bool all_equal (std::uint8_t) const noexcept;
   bool compare (size_type, const bytearray&) const noexcept;
   bool startswith (const bytearray&) const noexcept;
   bool endswith (const bytearray&) const noexcept;
   pos_type find (const bytearray&) const noexcept;
   pos_type rfind (const bytearray&) const noexcept;
+  void fill (value_type) noexcept;
+  void random () noexcept;
   void lpad (size_type, value_type = 0);
   void rpad (size_type, value_type = 0);
   void from_hexstring (const std::string&);
   std::string to_hexstring () const;
-  std::string to_string () const;
-  std::string dump () const;
+  std::string to_string (const std::string& = {}) const;
+  std::string dump (unsigned int = 0) const;
   bytearray slice (size_type, size_type) const;
+  std::vector <bytearray> split (const bytearray&) const;
 
 private:
   container_type data_;
@@ -265,6 +273,8 @@ private:
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 bytearray operator+ (const bytearray&, const bytearray&);
 bytearray operator^ (const bytearray&, const bytearray&);
+bytearray operator<< (const bytearray&, int);
+bytearray operator>> (const bytearray&, int);
 bool operator!= (const bytearray&, const bytearray&);
 
 } // namespace mobius
