@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -27,9 +27,7 @@
 #include <sstream>
 #include <stdexcept>
 
-namespace mobius
-{
-namespace decoder
+namespace mobius::decoder
 {
 namespace
 {
@@ -56,7 +54,7 @@ read (mobius::io::reader& reader, std::size_t size)
 //! \brief Constructor
 //! \param in reader object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-data_decoder::data_decoder (mobius::io::reader in)
+data_decoder::data_decoder (const mobius::io::reader& in)
   : in_ (in)
 {
 }
@@ -70,6 +68,15 @@ data_decoder::data_decoder (const mobius::bytearray& data)
 {
 }
 
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief Operator bool
+//! \return true If there is data to read, false otherwise
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+data_decoder::operator bool () const
+{
+  return !in_.eof ();
+}
+
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief Skip n bytes
 //! \param size size in bytes
@@ -438,12 +445,12 @@ std::string
 data_decoder::get_c_string (const std::string& encoding)
 {
   bytearray data;
-  
+
   // set ending block and read size according to encoding
   bytearray ending;
   std::uint64_t read_size;
 
-  
+
   if (encoding == "UTF-16LE" ||
       encoding == "UTF-16" ||
       encoding == "UTF-16BE")
@@ -489,17 +496,12 @@ data_decoder::get_guid ()
   uint16_t guid2 = get_uint16_le ();
   uint16_t guid3 = get_uint16_le ();
   uint16_t guid4 = get_uint16_be ();
-  bytearray guid5 = read (in_, 6);
+  uint16_t guid5 = get_uint16_be ();
+  uint32_t guid6 = get_uint32_be ();
 
   char buffer[64];
-  sprintf (buffer, "%08x-%04x-%04x-%04x-%02x%02x%02x%02x%02x%02x",
-           guid1, guid2, guid3, guid4,
-           guid5[0],
-           guid5[1],
-           guid5[2],
-           guid5[3],
-           guid5[4],
-           guid5[5]);
+  sprintf (buffer, "%08X-%04X-%04X-%04X-%04X%08X",
+           guid1, guid2, guid3, guid4, guid5, guid6);
 
   return buffer;
 }
@@ -597,11 +599,11 @@ data_decoder::get_ipv6 ()
 {
   std::stringstream stream;
   int state = 0;
-  
+
   for (int i = 0;i < 8;i++)
     {
       auto segment = get_uint16_be ();
-      
+
       switch (state)
         {
 
@@ -643,7 +645,7 @@ data_decoder::get_ipv6 ()
           break;
         }
     }
-    
+
   return stream.str ();
 }
 
@@ -657,11 +659,11 @@ data_decoder::get_ipv4_mapped_ipv6 ()
 {
   std::stringstream stream;
   int state = 0;
-  
+
   for (int i = 0;i < 6;i++)
     {
       auto segment = get_uint16_be ();
-      
+
       switch (state)
         {
 
@@ -718,5 +720,4 @@ data_decoder::get_ipv4_mapped_ipv6 ()
   return stream.str ();
 }
 
-} // namespace decoder
-} // namespace mobius
+} // namespace mobius::decoder
