@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -55,10 +55,6 @@
 // 3.5. fragment
 //   (pchar | "/" | "?")*
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-namespace mobius
-{
-namespace io
-{
 namespace
 {
 //! \brief RFC 3986 - section 2.3
@@ -84,7 +80,49 @@ static constexpr const char *URI_PATTERN = "(([A-Z][A-Z0-9+.-]*):)?(//([^/?#]*))
 static std::regex URI_REGEX (URI_PATTERN, std::regex::icase | std::regex::extended);
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Decode a string with %XX escape sequences
+//! \brief merge two URI paths
+//! \param base base URI
+//! \param rel relative URI
+//! \return merged path
+//! \see RFC 3986 - section 5.2.3
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static std::string
+merge_paths (const mobius::io::uri& base, const mobius::io::uri& rel)
+{
+  std::string path;
+
+  if (!base.get_authority ().empty () && base.get_path ().empty ())
+    path = '/' + rel.get_path ();
+
+  else
+    {
+      std::string::size_type pos = base.get_path ().rfind ('/');
+
+      if (pos == std::string::npos)
+        path = rel.get_path ();
+
+      else
+        path = base.get_path ().substr (0, pos) + '/' + rel.get_path ();
+    }
+
+  return path;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief remove dot segments
+//! \param path URI path
+//! \return path without "." and ".." dot segments
+//! \see RFC 3986 - section 5.2.4
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static std::string
+remove_dot_segments (const std::string& path)
+{
+  mobius::io::path p (path);
+  return to_string (p);
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief Encode a string with %XX escape sequences
 //! \param s Encoded string
 //! \param allowed Allowed chars (not converted)
 //! \return Decoded string
@@ -148,50 +186,10 @@ _decode_triplets (const std::string& s)
   return tmp;
 }
 
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief merge two URI paths
-//! \param base base URI
-//! \param rel relative URI
-//! \return merged path
-//! \see RFC 3986 - section 5.2.3
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-static std::string
-merge_paths (const uri& base, const uri& rel)
-{
-  std::string path;
-
-  if (!base.get_authority ().empty () && base.get_path ().empty ())
-    path = '/' + rel.get_path ();
-
-  else
-    {
-      std::string::size_type pos = base.get_path ().rfind ('/');
-
-      if (pos == std::string::npos)
-        path = rel.get_path ();
-
-      else
-        path = base.get_path ().substr (0, pos) + '/' + rel.get_path ();
-    }
-
-  return path;
-}
-
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief remove dot segments
-//! \param path URI path
-//! \return path without "." and ".." dot segments
-//! \see RFC 3986 - section 5.2.4
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-static std::string
-remove_dot_segments (const std::string& path)
-{
-  mobius::io::path p (path);
-  return to_string (p);
-}
-
 } // namespace
 
+namespace mobius::io
+{
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief Build URI from string
 //! \param value URI as string
@@ -221,7 +219,7 @@ uri::uri (const std::string& value)
     path = remove_dot_segments (path);
 
   path_ = path;
-  
+
   _normalize ();
 }
 
@@ -425,7 +423,7 @@ uri::get_query (const std::string& encoding) const
 {
   if (encoding.empty ())
     return query_;
-  
+
   return conv_charset_to_utf8 (_decode_triplets (query_), encoding);
 }
 
@@ -555,6 +553,22 @@ uri::get_extension () const
   return value;
 }
 
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief Get port number
+//! \return Port number
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+std::uint16_t
+uri::get_port_number () const
+{
+  std::uint16_t port_number = 0;
+
+  if (!port_.empty ())
+    port_number = strtol (port_.c_str (), nullptr, 10);
+
+  return port_number;
+}
+
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief Resolve an URI reference
 //! \param base base URI (not relative URI)
@@ -721,5 +735,4 @@ operator<< (std::ostream& stream, const uri& u)
   return stream;
 }
 
-} // namespace io
-} // namespace mobius
+} // namespace mobius::io
