@@ -28,7 +28,7 @@ namespace
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Constants
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-static constexpr int SCHEMA_VERSION = 12;
+static constexpr int SCHEMA_VERSION = 13;
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // History
@@ -64,6 +64,8 @@ static constexpr int SCHEMA_VERSION = 12;
  *
  *      12      New table evidence_source
  *
+ *      13      New table event
+ *
  * Create new table                     Rename old table
  * Copy data                            Create new table
  * Drop old table                       Copy data
@@ -232,6 +234,22 @@ case_schema (mobius::database::database db)
     "CREATE UNIQUE INDEX IF NOT EXISTS idx_evidence_tag "
            "ON evidence_tag (evidence_uid, name)");
 
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  // create table 'event'
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  db.execute (
+    "CREATE TABLE IF NOT EXISTS event ("
+                      "uid INTEGER PRIMARY KEY AUTOINCREMENT,"
+                 "item_uid INTEGER,"
+                "timestamp DATETIME NOT NULL,"
+                     "text TEXT NOT NULL,"
+    "FOREIGN KEY (item_uid) REFERENCES item (uid) ON DELETE CASCADE);"
+    );
+
+  db.execute (
+    "CREATE INDEX IF NOT EXISTS idx_event "
+           "ON event (item_uid)");
+
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   // upgrade database, if necessary
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
