@@ -3,7 +3,7 @@
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -56,6 +56,44 @@ bool case_sensitive_match (const std::string&, const std::string&);
 std::string to_hex (std::uint64_t, unsigned int = 1);
 std::string to_string (std::uint64_t, unsigned int = 1, char = '0');
 
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief Try to convert value to string
+//! \param v Value
+//! \return String representation of value
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+template <typename T> std::string
+to_string (const T& t)
+{
+  if constexpr (std::is_same_v <T, std::string> || std::is_same_v <T, const char *>)
+    return t;
+
+  else
+    return std::to_string (t);
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief Get first non-empty string from arguments
+//! \param args Arguments
+//! \return First non-empty argument
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+template <typename T> std::string
+first_of (const T& t)
+{
+  return to_string (t);
+}
+
+template <typename T, typename ...Args> std::string
+first_of (T t, Args... args)
+{
+  std::string s = first_of (t);
+
+  if (s.empty ())
+    return first_of (args...);
+
+  else
+    return s;
+}
+
 } // namespace mobius::string
 
 #endif
