@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -21,6 +21,7 @@
 //! \author Eduardo Aguiar
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 #include <pymobius.h>
+#include <pylist.h>
 #include "file.h"
 #include "folder.h"
 #include "reader.h"
@@ -37,7 +38,7 @@
 //! \return true/false
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 bool
-PyMobius_IO_File_Check (PyObject *pyobj)
+pymobius_io_file_check (PyObject *pyobj)
 {
   return PyObject_IsInstance (pyobj, (PyObject *) &io_file_t);
 }
@@ -48,7 +49,7 @@ PyMobius_IO_File_Check (PyObject *pyobj)
 //! \return new object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 PyObject *
-PyMobius_IO_File_from_cpp (mobius::io::file obj)
+pymobius_io_file_to_pyobject (mobius::io::file obj)
 {
   PyObject *ret = nullptr;
 
@@ -61,8 +62,7 @@ PyMobius_IO_File_from_cpp (mobius::io::file obj)
     }
   else
     {
-      Py_INCREF (Py_None);
-      ret = Py_None;
+      ret = mobius::py::pynone ();
     }
 
   return ret;
@@ -74,7 +74,7 @@ PyMobius_IO_File_from_cpp (mobius::io::file obj)
 //! \return file object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 mobius::io::file
-PyMobius_IO_File_as_cpp (PyObject *pyobj)
+pymobius_io_file_from_pyobject (PyObject *pyobj)
 {
   if (!PyObject_IsInstance (pyobj, (PyObject *) &io_file_t))
     throw std::invalid_argument (mobius::MOBIUS_EXCEPTION_MSG ("object type must be mobius.io.file"));
@@ -96,7 +96,7 @@ tp_getter_name (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -116,7 +116,7 @@ tp_getter_short_name (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -136,7 +136,7 @@ tp_getter_path (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -150,13 +150,13 @@ tp_setter_path (io_file_o *self, PyObject *value, void *)
 { 
   if (value == nullptr)
     { 
-      PyErr_SetString (PyExc_TypeError, "cannot delete 'path' attribute");
+      mobius::py::set_invalid_type_error ("cannot delete 'path' attribute");
       return -1;
     }
 
   if (!mobius::py::pystring_check (value))
     {
-      PyErr_SetString (PyExc_TypeError, "invalid type for 'path' attribute");
+      mobius::py::set_invalid_type_error ("invalid type for 'path' attribute");
       return -1;
     }
 
@@ -167,7 +167,7 @@ tp_setter_path (io_file_o *self, PyObject *value, void *)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
       return -1;
     }
 
@@ -188,7 +188,7 @@ tp_getter_inode (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -208,7 +208,7 @@ tp_getter_size (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -228,7 +228,7 @@ tp_getter_type (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -244,11 +244,11 @@ tp_getter_user_id (io_file_o *self)
 
   try
     {
-      ret = PyLong_FromLong (self->obj->get_user_id ());
+      ret = mobius::py::pylong_from_int (static_cast <int> (self->obj->get_user_id ()));
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -268,7 +268,7 @@ tp_getter_user_name (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -284,11 +284,11 @@ tp_getter_group_id (io_file_o *self)
 
   try
     {
-      ret = PyLong_FromLong (self->obj->get_group_id ());
+      ret = mobius::py::pylong_from_int (static_cast <int> (self->obj->get_group_id ()));
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -308,7 +308,7 @@ tp_getter_group_name (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -324,11 +324,11 @@ tp_getter_permissions (io_file_o *self)
 
   try
     {
-      ret = PyLong_FromLong (self->obj->get_permissions ());
+      ret = mobius::py::pylong_from_int (static_cast <int> (self->obj->get_permissions ()));
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -348,7 +348,7 @@ tp_getter_access_time (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -368,7 +368,7 @@ tp_getter_modification_time (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -388,7 +388,7 @@ tp_getter_metadata_time (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -408,7 +408,7 @@ tp_getter_creation_time (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -428,7 +428,7 @@ tp_getter_deletion_time (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -448,7 +448,7 @@ tp_getter_backup_time (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -578,7 +578,7 @@ tp_f_exists (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -598,7 +598,7 @@ tp_f_is_deleted (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -618,7 +618,7 @@ tp_f_is_reallocated (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -638,7 +638,7 @@ tp_f_is_hidden (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -658,7 +658,7 @@ tp_f_is_block_device (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -678,7 +678,7 @@ tp_f_is_char_device (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -698,7 +698,7 @@ tp_f_is_fifo (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -718,7 +718,7 @@ tp_f_is_symlink (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -738,7 +738,7 @@ tp_f_is_regular_file (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -758,7 +758,7 @@ tp_f_is_socket (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -778,7 +778,7 @@ tp_f_is_folder (io_file_o *)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -798,7 +798,7 @@ tp_f_is_file (io_file_o *)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -818,7 +818,7 @@ tp_f_get_extension (io_file_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -834,11 +834,11 @@ tp_f_get_parent (io_file_o *self, PyObject *)
 
   try
     {
-      ret = PyMobius_IO_Folder_from_cpp (self->obj->get_parent ());
+      ret = pymobius_io_folder_to_pyobject (self->obj->get_parent ());
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -859,7 +859,7 @@ tp_f_new_sibling_by_name (io_file_o *self, PyObject *args)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_TypeError, e.what ());
+      mobius::py::set_invalid_type_error (e.what ());
       return nullptr;
     }
 
@@ -868,11 +868,11 @@ tp_f_new_sibling_by_name (io_file_o *self, PyObject *args)
 
   try
     {
-      ret = PyMobius_IO_File_from_cpp (self->obj->new_sibling_by_name (arg_name));
+      ret = pymobius_io_file_to_pyobject (self->obj->new_sibling_by_name (arg_name));
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -893,7 +893,7 @@ tp_f_new_sibling_by_extension (io_file_o *self, PyObject *args)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_TypeError, e.what ());
+      mobius::py::set_invalid_type_error (e.what ());
       return nullptr;
     }
 
@@ -902,11 +902,11 @@ tp_f_new_sibling_by_extension (io_file_o *self, PyObject *args)
 
   try
     {
-      ret = PyMobius_IO_File_from_cpp (self->obj->new_sibling_by_extension (arg_ext));
+      ret = pymobius_io_file_to_pyobject (self->obj->new_sibling_by_extension (arg_ext));
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -923,13 +923,11 @@ tp_f_reload (io_file_o *self, PyObject *)
   try
     {
       self->obj->reload ();
-
-      Py_INCREF (Py_None);
-      ret = Py_None;
+      ret = mobius::py::pynone ();
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -950,13 +948,13 @@ tp_f_copy (io_file_o *self, PyObject *args)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_ValueError, e.what ());
+      mobius::py::set_value_error (e.what ());
       return nullptr;
     }
 
-  if (!PyMobius_IO_File_Check (arg_to) && !PyMobius_IO_Folder_Check (arg_to))
+  if (!pymobius_io_file_check (arg_to) && !pymobius_io_folder_check (arg_to))
     {
-      PyErr_SetString (PyExc_TypeError, "invalid destination type");
+      mobius::py::set_invalid_type_error ("invalid destination type");
       return nullptr;
     }
 
@@ -965,17 +963,17 @@ tp_f_copy (io_file_o *self, PyObject *args)
 
   try
     {
-      if (PyMobius_IO_File_Check (arg_to))
-        self->obj->copy (PyMobius_IO_File_as_cpp (arg_to));
+      if (pymobius_io_file_check (arg_to))
+        self->obj->copy (pymobius_io_file_from_pyobject (arg_to));
 
       else
-        self->obj->copy (PyMobius_IO_Folder_as_cpp (arg_to));
+        self->obj->copy (pymobius_io_folder_from_pyobject (arg_to));
 
       ret = mobius::py::pynone ();
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -996,13 +994,13 @@ tp_f_move (io_file_o *self, PyObject *args)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_ValueError, e.what ());
+      mobius::py::set_invalid_type_error (e.what ());
       return nullptr;
     }
 
-  if (!PyMobius_IO_File_Check (arg_to) && !PyMobius_IO_Folder_Check (arg_to))
+  if (!pymobius_io_file_check (arg_to) && !pymobius_io_folder_check (arg_to))
     {
-      PyErr_SetString (PyExc_TypeError, "invalid destination type");
+      mobius::py::set_invalid_type_error ("invalid destination type");
       return nullptr;
     }
 
@@ -1011,17 +1009,17 @@ tp_f_move (io_file_o *self, PyObject *args)
 
   try
     {
-      if (PyMobius_IO_File_Check (arg_to))
-        self->obj->move (PyMobius_IO_File_as_cpp (arg_to));
+      if (pymobius_io_file_check (arg_to))
+        self->obj->move (pymobius_io_file_from_pyobject (arg_to));
 
       else
-        self->obj->move (PyMobius_IO_Folder_as_cpp (arg_to));
+        self->obj->move (pymobius_io_folder_from_pyobject (arg_to));
 
       ret = mobius::py::pynone ();
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -1042,7 +1040,7 @@ tp_f_remove (io_file_o *self, PyObject *)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -1063,7 +1061,7 @@ tp_f_rename (io_file_o *self, PyObject *args)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_TypeError, e.what ());
+      mobius::py::set_invalid_type_error (e.what ());
       return nullptr;
     }
 
@@ -1077,7 +1075,7 @@ tp_f_rename (io_file_o *self, PyObject *args)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -1093,11 +1091,11 @@ tp_f_new_reader (io_file_o *self, PyObject *)
 
   try
     {
-      ret = PyMobius_IO_Reader_from_cpp (self->obj->new_reader ());
+      ret = pymobius_io_reader_to_pyobject (self->obj->new_reader ());
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -1118,7 +1116,7 @@ tp_f_new_writer (io_file_o *self, PyObject *args)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_TypeError, e.what ());
+      mobius::py::set_invalid_type_error (e.what ());
       return nullptr;
     }
 
@@ -1127,298 +1125,16 @@ tp_f_new_writer (io_file_o *self, PyObject *args)
 
   try
     {
-      ret = PyMobius_IO_Writer_from_cpp (self->obj->new_writer (arg_overwrite));
+      ret = pymobius_io_writer_to_pyobject (self->obj->new_writer (arg_overwrite));
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
 }
 
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief set_tag method
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-static PyObject *
-tp_f_set_tag (io_file_o *self, PyObject *args)
-{
-  // parse input args
-  std::string arg_tag;
-
-  try
-    {
-      arg_tag = mobius::py::get_arg_as_std_string (args, 0);
-    }
-  catch (const std::exception& e)
-    {
-      PyErr_SetString (PyExc_TypeError, e.what ());
-      return nullptr;
-    }
-
-  // execute C++ code
-  PyObject *ret = nullptr;
-
-  try
-    {
-      self->obj->set_tag (arg_tag);
-      ret = mobius::py::pynone ();
-    }
-  catch (const std::exception& e)
-    {
-      PyErr_SetString (PyExc_Exception, e.what ());
-    }
-
-  return ret;
-}
-
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief reset_tag method
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-static PyObject *
-tp_f_reset_tag (io_file_o *self, PyObject *args)
-{
-  // parse input args
-  std::string arg_tag;
-
-  try
-    {
-      arg_tag = mobius::py::get_arg_as_std_string (args, 0);
-    }
-  catch (const std::exception& e)
-    {
-      PyErr_SetString (PyExc_TypeError, e.what ());
-      return nullptr;
-    }
-
-  // execute C++ code
-  PyObject *ret = nullptr;
-
-  try
-    {
-      self->obj->reset_tag (arg_tag);
-      ret = mobius::py::pynone ();
-    }
-  catch (const std::exception& e)
-    {
-      PyErr_SetString (PyExc_Exception, e.what ());
-    }
-
-  return ret;
-}
-
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief has_tag method
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-static PyObject *
-tp_f_has_tag (io_file_o *self, PyObject *args)
-{
-  // parse input args
-  std::string arg_tag;
-
-  try
-    {
-      arg_tag = mobius::py::get_arg_as_std_string (args, 0);
-    }
-  catch (const std::exception& e)
-    {
-      PyErr_SetString (PyExc_TypeError, e.what ());
-      return nullptr;
-    }
-
-  // execute C++ code
-  PyObject *ret = nullptr;
-
-  try
-    {
-      ret = mobius::py::pybool_from_bool (self->obj->has_tag (arg_tag));
-    }
-  catch (const std::exception& e)
-    {
-      PyErr_SetString (PyExc_Exception, e.what ());
-    }
-
-  return ret;
-}
-
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief get_tags method
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-static PyObject *
-tp_f_get_tags (io_file_o *self, PyObject *)
-{
-  PyObject *ret = nullptr;
-
-  try
-    {
-      ret = mobius::py::pylist_from_cpp_container (
-               self->obj->get_tags (),
-               mobius::py::pystring_from_std_string
-            );
-    }
-  catch (const std::exception& e)
-    {
-      PyErr_SetString (PyExc_Exception, e.what ());
-    }
-
-  return ret;
-}
-
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief <i>has_metadata</i> method implementation
-//! \param self Object
-//! \param args Argument list
-//! \return true/false
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-static PyObject *
-tp_f_has_metadata (io_file_o *self, PyObject *args)
-{
-  // Parse input args
-  std::string arg_name;
-
-  try
-    {
-      arg_name = mobius::py::get_arg_as_std_string (args, 0);
-    }
-  catch (const std::exception& e)
-    {
-      PyErr_SetString (PyExc_TypeError, e.what ());
-      return nullptr;
-    }
-
-  // Execute C++ function
-  PyObject *ret = nullptr;
-
-  try
-    {
-      ret = mobius::py::pybool_from_bool (self->obj->has_metadata (arg_name));
-    }
-  catch (const std::exception& e)
-    {
-      PyErr_SetString (PyExc_Exception, e.what ());
-    }
-
-  // Return value
-  return ret;
-}
-
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief <i>get_metadata</i> method implementation
-//! \param self Object
-//! \param args Argument list
-//! \return Metadata value
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-static PyObject *
-tp_f_get_metadata (io_file_o *self, PyObject *args)
-{
-  // Parse input args
-  std::string arg_name;
-
-  try
-    {
-      if (mobius::py::get_arg_size (args) > 0)
-        arg_name = mobius::py::get_arg_as_std_string (args, 0);
-    }
-  catch (const std::exception& e)
-    {
-      PyErr_SetString (PyExc_TypeError, e.what ());
-      return nullptr;
-    }
-
-  // Execute C++ function
-  PyObject *ret = nullptr;
-
-  try
-    {
-      if (arg_name.empty ())
-        ret = PyMobius_Pod_Map_to_python (self->obj->get_metadata ());
-
-      else
-        ret = PyMobius_Pod_Data_from_cpp (self->obj->get_metadata (arg_name));
-    }
-  catch (const std::exception& e)
-    {
-      PyErr_SetString (PyExc_Exception, e.what ());
-    }
-
-  // Return value
-  return ret;
-}
-
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief <i>set_metadata</i> method implementation
-//! \param self Object
-//! \param args Argument list
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-static PyObject *
-tp_f_set_metadata (io_file_o *self, PyObject *args)
-{
-  // Parse input args
-  std::string arg_name;
-  mobius::pod::data arg_value;
-
-  try
-    {
-      arg_name = mobius::py::get_arg_as_std_string (args, 0);
-      arg_value = PyMobius_Pod_Data_as_cpp (mobius::py::get_arg (args, 1));
-    }
-  catch (const std::exception& e)
-    {
-      PyErr_SetString (PyExc_TypeError, e.what ());
-      return nullptr;
-    }
-
-  // Execute C++ function
-  try
-    {
-      self->obj->set_metadata (arg_name, arg_value);
-    }
-  catch (const std::exception& e)
-    {
-      PyErr_SetString (PyExc_Exception, e.what ());
-      return nullptr;
-    }
-
-  // return None
-  return mobius::py::pynone ();
-}
-
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief <i>remove_metadata</i> method implementation
-//! \param self Object
-//! \param args Argument list
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-static PyObject *
-tp_f_remove_metadata (io_file_o *self, PyObject *args)
-{
-  // Parse input args
-  std::string arg_name;
-
-  try
-    {
-      arg_name = mobius::py::get_arg_as_std_string (args, 0);
-    }
-  catch (const std::exception& e)
-    {
-      PyErr_SetString (PyExc_TypeError, e.what ());
-      return nullptr;
-    }
-
-  // Execute C++ function
-  try
-    {
-      self->obj->remove_metadata (arg_name);
-    }
-  catch (const std::exception& e)
-    {
-      PyErr_SetString (PyExc_Exception, e.what ());
-      return nullptr;
-    }
-
-  // return None
-  return mobius::py::pynone ();
-}
-
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief <i>get_streams</i> method implementation
 //! \param self Object
@@ -1435,13 +1151,13 @@ tp_f_get_streams (io_file_o *self, PyObject *)
     {
       ret = mobius::py::pylist_from_cpp_container (
                self->obj->get_streams (),
-               PyMobius_Io_Stream_from_cpp
+               pymobius_io_stream_to_pyobject
             );
 
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   // Return value
@@ -1591,54 +1307,6 @@ static PyMethodDef tp_methods[] =
     METH_VARARGS,
     "Create new writer"
   },
-  {
-    (char *) "set_tag",
-    (PyCFunction) tp_f_set_tag,
-    METH_VARARGS,
-    "Set tag"
-  },
-  {
-    (char *) "reset_tag",
-    (PyCFunction) tp_f_reset_tag,
-    METH_VARARGS,
-    "Reset tag"
-  },
-  {
-    (char *) "has_tag",
-    (PyCFunction) tp_f_has_tag,
-    METH_VARARGS,
-    "Check if tag is set"
-  },
-  {
-    (char *) "get_tags",
-    (PyCFunction) tp_f_get_tags,
-    METH_VARARGS,
-    "Get tags"
-  },
-  {
-    (char *) "has_metadata",
-    (PyCFunction) tp_f_has_metadata,
-    METH_VARARGS,
-    "Check if metadata exists"
-  },
-  {
-    (char *) "get_metadata",
-    (PyCFunction) tp_f_get_metadata,
-    METH_VARARGS,
-    "Get metadata value"
-  },
-  {
-    (char *) "set_metadata",
-    (PyCFunction) tp_f_set_metadata,
-    METH_VARARGS,
-    "Set metadata"
-  },
-  {
-    (char *) "remove_metadata",
-    (PyCFunction) tp_f_remove_metadata,
-    METH_VARARGS,
-    "Remove metadata"
-  },
   {
     (char *) "get_streams",
     (PyCFunction) tp_f_get_streams,
@@ -1655,7 +1323,7 @@ static void
 tp_dealloc (io_file_o *self)
 {
   delete self->obj;
-  self->ob_type->tp_free ((PyObject*) self);
+  Py_TYPE (self)->tp_free ((PyObject*) self);
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -1710,4 +1378,5 @@ PyTypeObject io_file_t =
   0,                                       		// tp_weaklist
   0,                                       		// tp_del
   0,                                       		// tp_version_tag
+  0,                                       		// tp_finalize
 };
