@@ -3,7 +3,7 @@
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -22,8 +22,8 @@
 
 namespace mobius::py
 {
-//! \brief GIL auto release/acquire class
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief GIL auto release/acquire class
 //! \author Eduardo Aguiar
 //
 // Use: auto v = mobius::py::GIL () (expression)
@@ -62,11 +62,41 @@ public:
     state_ = nullptr;
     return std::move (r);
   }
-  
+
 private:
   PyThreadState *state_;
 };
 
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief GIL auto acquire/release class
+//! \author Eduardo Aguiar
+//
+// Use: auto v = mobius::py::GILHolder () (expression)
+// Example: auto data = mobius::py::GIL () (self->obj->get_bytearray ())
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+class GIL_holder
+{
+public:
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  //! \brief Constructor
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  GIL_holder () noexcept
+    : state_ (PyGILState_Ensure ())
+  {
+  }
+
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  //! \brief Destructor
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  ~GIL_holder ()
+  {
+    PyGILState_Release (state_);
+  }
+
+private:
+  PyGILState_STATE state_;
+};
+
 } // namespace mobius::py
 
 #endif
